The function highlight private alleles by strata, using a GDS or tidy file or object.
Arguments
- data
A tidy genomic data frame or another genomic object supported by the calling function.
- strata
(path or object) The strata file or object. Additional documentation is available in
read_strata. Use that function to whitelist/blacklist populations/individuals. Option to setpop.levels/pop.labelsis also available.- verbose
Logical indicating whether progress messages are emitted. Default:
verbose = FALSE.
Value
A list with an object highlighting private alleles by markers and strata and a second object with private alleles summarized by strata.
Author
Thierry Gosselin thierrygosselin@icloud.com