Reports the required and optional R packages used by radr and checks whether
the optional bcftools and BayeScan executables are available. The
function is diagnostic: it does not install packages or modify a Conda
environment.
Reports the required and optional R packages used by radr and checks whether
the optional bcftools and BayeScan executables are available. The
function is diagnostic: it does not install packages or modify a Conda
environment.